# trickkiste

## suppress
- formerly known as `quieten` or `quietverbose`


apparat/dev/quietverbose
biograph/dev/quietverbose
checkmk-pip/dev/quietverbose
einefreude/dev/quietverbose
machinery-killme/--force/quietverbose
magicwall.io/dev/quietverbose
magicwall.io/.venv/lib/python3.10/site-packages/cmk_dev/listen_std.py
medit/dev/quietverbose
minimon/dev/quietverbose
minimon.temp/dev/quietverbose
pocketrockit/dev/quietverbose
pyqtdeploy-fromscratch/pyqt5tools/dev/quieten
qrm/dev/quietverbose
silmaril/dev/quietverbose
smdr/dev/quietverbose
synthi/dev/quieten
trickkiste/dev/quietverbose
trickkiste/trickkiste/std_suppress.py
ttrace/dev/quietverbose
wth/dev/quietverbose

